Simple test
------------

Ensure your device works with one of these simple tests.

.. literalinclude:: ../examples/icm20x_icm20649_simpletest.py
    :caption: examples/icm20x_icm20649_simpletest.py
    :linenos:

.. literalinclude:: ../examples/icm20x_icm20948_simpletest.py
    :caption: examples/icm20x_icm20948_simpletest.py
    :linenos:
